package common

import (
	"Cold_Logistic/internal/pkg/common/codex"
	"Cold_Logistic/internal/pkg/common/global"
	"Cold_Logistic/internal/server/adapter/http/middleware"
	"Cold_Logistic/internal/server/application/commonsrv"
	"Cold_Logistic/internal/server/application/devicesrv"
	"Cold_Logistic/internal/server/infra/dao"
	"github.com/gin-gonic/gin"
	"gogs.baozhida.cn/Cold_Logistic_libs/pkg/contrib/core"
	"gogs.baozhida.cn/Cold_Logistic_libs/pkg/contrib/errors"
)

func Register(r *gin.RouterGroup) {
	api := NewApi()
	common := r.Group("/common")
	common.Use(middleware.Auth())
	common.GET("/provinceList", api.provinceList)     // 省市区列表
	common.GET("/sensorDataList", api.sensorDataList) // 设备数据列表
	common.GET("/logisticList", api.logisticList)     // 设备数据列表
	return
}

type Api struct{}

func NewApi() Api {
	return Api{}
}

func (api Api) provinceList(c *gin.Context) {
	srv := commonsrv.NewCommonService(dao.NewDataStore(global.CommonConnectRepoInst.StoreDB))
	data, err := srv.ProvinceList(c)
	if err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrQueryFailed, ""))
		return
	}
	core.WriteResponse(c, nil, data)
}

// sensorDataList 设备数据列表
func (api Api) sensorDataList(c *gin.Context) {
	req := devicesrv.SnDataListReqVO{}
	if err := c.BindJSON(&req); err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrBindJSON, ""))
		return
	}

	if err := req.Validate(); err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrParamValidate, "参数验证失败："))
		return
	}

	srv := devicesrv.NewDeviceService(dao.NewDataStore(global.CommonConnectRepoInst.StoreDB))
	res, err := srv.SnDataList(c, req)
	if err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrQueryFailed, ""))
		return
	}
	core.WriteResponse(c, nil, res)
}

// logisticList 物流公司列表
func (api Api) logisticList(c *gin.Context) {
	req := commonsrv.LogisticListReqVO{}
	if err := c.BindJSON(&req); err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrBindJSON, ""))
		return
	}

	srv := commonsrv.NewCommonService(dao.NewDataStore(global.CommonConnectRepoInst.StoreDB))
	res, err := srv.LogisticList(c, req)
	if err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrQueryFailed, ""))
		return
	}
	core.WriteResponse(c, nil, res)
}
