package myself

import (
	"Cold_Logistic/internal/pkg/common/codex"
	"Cold_Logistic/internal/pkg/common/global"
	"Cold_Logistic/internal/server/application/myselfsrv"
	"Cold_Logistic/internal/server/infra/dao"
	"github.com/gin-gonic/gin"
	"gogs.baozhida.cn/Cold_Logistic_libs/pkg/contrib/core"
	"gogs.baozhida.cn/Cold_Logistic_libs/pkg/contrib/errors"
)

func (api Api) addressPage(c *gin.Context) {
	req := myselfsrv.AddressPageReqVO{}
	if err := c.BindJSON(&req); err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrBindJSON, ""))
		return
	}

	if err := req.Validate(); err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrParamValidate, "参数验证失败："))
		return
	}

	srv := myselfsrv.NewMyselfService(dao.NewDataStore(global.CommonConnectRepoInst.StoreDB))
	res, err := srv.AddressPage(c, req)
	if err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrSaveFailed, ""))
		return
	}
	core.WriteResponse(c, nil, res)
}

func (api Api) addAddress(c *gin.Context) {
	req := myselfsrv.AddAddressReqVO{}
	if err := c.BindJSON(&req); err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrBindJSON, ""))
		return
	}

	if err := req.Validate(); err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrParamValidate, "参数验证失败："))
		return
	}

	srv := myselfsrv.NewMyselfService(dao.NewDataStore(global.CommonConnectRepoInst.StoreDB))
	res, err := srv.AddAddress(c, req)
	if err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrSaveFailed, ""))
		return
	}
	core.WriteResponse(c, nil, res)
}

func (api Api) updateAddress(c *gin.Context) {
	req := myselfsrv.UpdateAddressReqVO{}
	if err := c.BindJSON(&req); err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrBindJSON, ""))
		return
	}

	if err := req.Validate(); err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrParamValidate, "参数验证失败："))
		return
	}

	srv := myselfsrv.NewMyselfService(dao.NewDataStore(global.CommonConnectRepoInst.StoreDB))
	res, err := srv.UpdateAddress(c, req)
	if err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrSaveFailed, ""))
		return
	}
	core.WriteResponse(c, nil, res)
}

func (api Api) deleteAddress(c *gin.Context) {
	req := myselfsrv.DeleteAddressReqVO{}
	if err := c.BindJSON(&req); err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrBindJSON, ""))
		return
	}

	if err := req.Validate(); err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrParamValidate, "参数验证失败："))
		return
	}

	srv := myselfsrv.NewMyselfService(dao.NewDataStore(global.CommonConnectRepoInst.StoreDB))
	err := srv.DeleteAddress(c, req)
	if err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrDeletedFailed, ""))
		return
	}
	core.WriteResponse(c, nil, nil)
}
